$(document).on('pagebeforeshow',function(e,data){
    // getting the id of current page
    var currentPageId = $.mobile.activePage.attr('id');
    // page2 denotes schedule
    if (currentPageId == 'loginPage')
    {
        if (!isGuestUser())
        {
            // if logged in then redirect to main page
            window.location = "./main.html";
        }
        $("#loginForm").unbind("submit", loginButtonAction);
    	// binding event on login form submit
        $("#loginForm").bind("submit", loginButtonAction);
    }
	else if (currentPageId == 'loginInitPage')
	{
		if (!isGuestUser())
		{
			window.location = "./main.html";
		}
		$("#user_guest").bind("click", function(){
            window.location = "./main.html";
        });
	}
    else if (currentPageId == 'registerPage')
    {
        // check if user is logged in
        if (!isGuestUser())
        {
            // if logged in then redirect to main page
            window.location = "./main.html";
            $("#registerFormContainer").addClass("hidden");
        }
        else
        {
            // if not logged in then show register form
            $("#registerFormContainer").removeClass("hidden");
        }
        $("#registerForm").unbind("submit", registerButtonAction);
    	// binding event on register form submit
        $("#registerForm").bind("submit", registerButtonAction);
    }
});

/**
 * function performs the login action
 * makes ajax call to let the user login into the app
 */
function loginButtonAction(event)
{
	// prevent page redirect
    event.preventDefault();
    var userEmail = $("#user_email").val();
    var userPassword = $("#user_password").val();
    var form_errors = [];
    if ( userEmail == "" )
    {
        form_errors.push(" -Email can not be empty")
    }
    if ( userPassword == "" )
    {
        form_errors.push(" -Password can not be empty")
    }

    if (form_errors.length > 0)
    {
        alert("Please fix following issues\n\r" + form_errors.join("\n\r"));
        return false;
    }
    else
    {
        data = {
            'userEmail' : userEmail,
            'userPassword' : userPassword
        };
        showLoading();
        setTimeout(function(){
            $.ajax({
                url: baseUrl + "/site/userLoginFromApp",   // url for AJAX call
                dataType: "json",
                data: data,
                type: "POST",
                async: false,
                success: function (result) {
                    if (result.success == "1")
                    {
                        var userDetails = {
                            'id' : result.userId,
                            'email' : userEmail,
                            'firstName' : result.firstName,
                            'lastName' : result.lastName,
                            'phone' : result.phone,
                            'eventQuestionAnswers' : result.eventQuestionAnswers
                        };
                        window.localStorage.setItem('userDetails', JSON.stringify(userDetails));
                        // register user device to the server
                        if (window.localStorage.getItem('deviceToken'))
                        {
                            registerDeviceToken(window.localStorage.getItem('deviceToken'), device.platform, JSON.stringify(userDetails));
                        }
                        window.location.href = 'main.html';
                    }
                    else
                    {
                        alert(result.message);
                        hideLoading();
                        return false;
                    }
                },
                error: function (request,error) {
                    alert('An active internet connection is required to run this application');
                    hideLoading();
                    return false;
                }
            });
        },300);
    }
    return false;
}


/**
 * function performs the register action for a user
 * makes ajax call to register a user
 */
function registerButtonAction(event)
{
	// prevent page redirect
    event.preventDefault();
    var userEmail = $("#user_register_email").val();
    var userFirstName = $("#user_first_name").val();
    var userLastName = $("#user_last_name").val();
    var userPhone = $("#user_phone").val();

    var formErrors = [];

    if (userEmail == "")
    {
        formErrors.push(" -Email can not be empty");
    }
    if (userFirstName == "")
    {
        formErrors.push(" -First Name can not be empty");
    }
    if (userPhone == "")
    {
        formErrors.push(" -Phone Number can not be empty");
    }
    else
    {
        if (isNaN(userPhone))
        {
            formErrors.push(" -Enter a valid phone number");
        }
    }
    if (formErrors.length > 0)
    {
        alert("Please fix the following issues\n\r" + formErrors.join("\n\r"));
        return false;
    }
    else
    {
        var data = {
            'User' : {
                'email' : userEmail,
                'first_name' : userFirstName,
                'last_name' : userLastName,
                'phone' : userPhone
            },
            'registerFromMobileApp' : true
        };
        
        if (checkConnection())
        {
            showLoading();
            setTimeout(function(){
                $.ajax({
                    url: baseUrl + "/site/register",   // url for AJAX call
                    dataType: "json",
                    data: data,
                    type: "POST",
                    async: false,
                    success: function (result) {
                        if (result.success == "1")
                        {
                            var userDetails = {
                                'id' : result.userId,
                                'email' : userEmail,
                                'firstName' : result.firstName,
                                'lastName' : result.lastName,
                                'phone' : result.phone
                            };
                            window.localStorage.setItem('userDetails', JSON.stringify(userDetails));
                            window.location.href = 'main.html';
                        }
                        else
                        {
                            alert(result.message);
                            hideLoading();
                            return false;
                        }
                    },
                    error: function (request,error) {
                        alert('An active internet connection is required to run this application');
                        hideLoading();
                        return false;
                    }
                });
            },300);
        }
        else
        {
            ui_alert('An active internet connection is required.');
        }
    }
    return false;
}

/**
 * function makes ajax request to fetch the logo image data and displays it to
 * the logo image object
 */
function fetchLogoImage(logoImageObject)
{
    $.ajax({
        url: baseUrl + "/images/getLogoImageData",   // url for AJAX call
        dataType: "json",
        type: "POST",
        async: false,
        beforeSend: function() {
            // showing loading icon before AJAX request
            showLoading();
        },
        success: function (result) {
            if (result.success == "1")
            {

                var logoImageInfo = "data:"+ result.mimeType +";base64," + result.encodedImage;
                // saving logo image data as local storage
                window.localStorage.setItem("logoImageData", logoImageInfo);
                // displaying logo image
                $(logoImageObject).prop('src', logoImageInfo);
                window.localStorage.setItem("isLogoImageChanged", "false");
                hideLoading();
            }
            else
            {
               hideLoading();
            }
        },
        error: function (request,error) {
            hideLoading();
        }
    });
}
